@@ -14,6 +14,14 @@ NETWORKS = {
         "opera",
         "testnet",
     ],
+    "arbitrum": [
+        "mainnet",
+        "testnet",
+    ],
+    "optimism": [
+        "mainnet",
+        "kovan",
+    ],
 }
 
 
