@@ -3,9 +3,12 @@ from json.decoder import JSONDecodeError
 from typing import Iterator, Optional
 
 from ape.api import ExplorerAPI, ReceiptAPI
+from ape.contracts import ContractInstance
+from ape.exceptions import ProviderNotConnectedError
 from ape.types import AddressType, ContractType
 
 from ape_etherscan.client import ClientFactory, get_etherscan_uri
+from ape_etherscan.verify import SourceVerifier
 
 
 class Etherscan(ExplorerAPI):
@@ -37,7 +40,16 @@ class Etherscan(ExplorerAPI):
         except JSONDecodeError:
             return None
 
-        return ContractType.parse_obj({"abi": abi, "contractName": source_code.name})
+        contract_type = ContractType(abi=abi, contractName=source_code.name)
+        if source_code.name == "Vyper_contract" and "symbol" in contract_type.view_methods:
+            try:
+                checksummed_address = self.provider.network.ecosystem.decode_address(address)
+                contract = ContractInstance(checksummed_address, contract_type)
+                contract_type.name = contract.symbol() or contract_type.name
+            except ProviderNotConnectedError:
+                pass
+
+        return contract_type
 
     def get_account_transactions(self, address: AddressType) -> Iterator[ReceiptAPI]:
         client = self._client_factory.get_account_client(address)
@@ -45,8 +57,15 @@ class Etherscan(ExplorerAPI):
             if "confirmations" in receipt_data:
                 receipt_data["required_confirmations"] = receipt_data.pop("confirmations")
             if "txreceipt_status" in receipt_data:
-                # NOTE: Ethrscan uses `""` for `0` in the receipt status.
+                # NOTE: Etherscan uses `""` for `0` in the receipt status.
                 status = receipt_data.pop("txreceipt_status") or 0
                 receipt_data["status"] = status
 
+            if receipt_data.get("nonce") == "":
+                receipt_data["nonce"] = None
+
             yield self.network.ecosystem.decode_receipt(receipt_data)
+
+    def publish_contract(self, address: AddressType):
+        verifier = SourceVerifier(address, self._client_factory)
+        return verifier.attempt_verification()
